========
Meditate
========

A command line meditation clock.

The `bell sound`_, taken from freesound.org_, is licensed under
CC0_.

.. _`bell sound`: sound/140128__jetrye__bell-meditation-cleaned.wav
.. _freesound.org: https://freesound.org/people/JetRye/sounds/140128/
.. _CC0: https://creativecommons.org/publicdomain/zero/1.0/
